@@ -34,7 +34,10 @@ def _safe_cast(val, to_type, default=None):
         return default
 
 
-def _is_same_dict(a: dict, b: dict): return json.dumps(a, sort_keys=True) == json.dumps(b, sort_keys=True)
+def _hash_dict(value: dict): return json.dumps(value, sort_keys=True)
+
+
+def _is_same_dict(a: dict, b: dict): return _hash_dict(a) == _hash_dict(b)
 
 
 def _dict_without_key(a: dict, key: str):
@@ -44,6 +47,31 @@ def _dict_without_key(a: dict, key: str):
     return no_key
 
 
+def _group_nodes(nodes: List[dict]):
+    def group(groups: dict, node: dict):
+        type = node.get('type')
+        id = node.get('id')
+        if type and id:
+            groups[type] = groups.get(type, {})
+            groups[type][id] = node
+        return groups
+
+    return reduce(group, nodes, {})
+
+
+def _hash_nodes(nodes: List[dict]):
+    def group(groups: dict, node: dict):
+        type = node.get('type')
+        id = node.get('id')
+        if type and id:
+            # store the hash of the node without the `id` for uniqueness check
+            key = _hash_dict(_dict_without_key(node, 'id'))
+            groups[key] = groups.get(key, []) + [node]
+        return groups
+
+    return reduce(group, nodes, {})
+
+
 def _get_by_key(x, y):
     return x if x is None else (
         x.get(y) if isinstance(x, dict) else list(map(lambda v: _get_dict_key(v, y), x))
@@ -85,10 +113,8 @@ def _value_average(node: dict, default=0):
     return value if is_number else list_average(value, default)
 
 
-def _find_linked_node(nodes: list, linked_node: dict):
-    type = linked_node.get('type')
-    id = linked_node.get('id')
-    return next((node for node in nodes if node['type'] == type and node['id'] == id), None) if type and id else None
+def _find_linked_node(node_map: dict, node: dict):
+    return node_map.get(node.get('type'), {}).get(node.get('id'))
 
 
 def _is_before_today(date: str): return safe_parse_date(date).date() < datetime.now().date()
