@@ -1,4 +1,4 @@
-from hestia_earth.schema import SchemaType, CycleFunctionalUnitMeasure, SiteSiteType, TermTermType
+from hestia_earth.schema import SchemaType, CycleFunctionalUnit, SiteSiteType, TermTermType
 from hestia_earth.utils.tools import flatten, list_sum
 from hestia_earth.utils.date import diff_in_days, is_in_days
 from hestia_earth.utils.api import find_node
@@ -52,13 +52,13 @@ def validate_cycleDuration(cycle: dict):
     }
 
 
-def validate_functionalUnitMeasure(cycle: dict, site: dict):
+def validate_functionalUnit(cycle: dict, site: dict):
     site_type = site.get('siteType')
-    value = cycle.get('functionalUnitMeasure')
-    expected = CycleFunctionalUnitMeasure._1_HA.value
+    value = cycle.get('functionalUnit')
+    expected = CycleFunctionalUnit._1_HA.value
     return site_type not in SITE_TYPES_RESTRICTED or value == expected or {
         'level': 'error',
-        'dataPath': '.functionalUnitMeasure',
+        'dataPath': '.functionalUnit',
         'message': f"must equal to {expected}"
     }
 
@@ -208,8 +208,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_properties_default_value(cycle, 'practices', 'properties'),
         validate_list_duplicate_values(cycle, 'practices', 'term.termType', TermTermType.EXCRETAMANAGEMENT.value)
     ] if len(cycle.get('practices', [])) > 0 else []) + flatten([
-        validate_functionalUnitMeasure(cycle, site)
-    ] if 'functionalUnitMeasure' in cycle and site else []) + flatten([
+        validate_functionalUnit(cycle, site)
+    ] if 'functionalUnit' in cycle and site else []) + flatten([
         validate_list_dates(cycle, 'transformations'),
         validate_list_dates_format(cycle, 'transformations'),
         validate_list_date_lt_today(cycle, 'transformations', ['startDate', 'endDate']),
