@@ -5,9 +5,9 @@ from hestia_earth.validation.utils import _filter_list, _list_sum
 
 
 def validate_longFallowPeriod(practices: list):
-    longFallowPeriod = find_term_match(practices, 'longFallowPeriod')
-    longFallowPeriod_index = practices.index(longFallowPeriod)
-    value = longFallowPeriod.get('value', 0)
+    longFallowPeriod = find_term_match(practices, 'longFallowPeriod', None)
+    longFallowPeriod_index = practices.index(longFallowPeriod) if longFallowPeriod else 0
+    value = longFallowPeriod.get('value', 0) if longFallowPeriod else 0
     rotationDuration = find_term_match(practices, 'rotationDuration').get('value', 0)
     return value == 0 or ((rotationDuration - value) / value) < 5 or {
         'level': 'error',
