@@ -9,7 +9,10 @@ from .shared import (
     validate_list_date_lt_today, validate_date_lt_today, validate_properties_default_value
 )
 from .infrastructure import validate_lifespan
-from .measurement import validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique
+from .measurement import (
+    validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique,
+    validate_require_startDate_endDate
+)
 from .practice import validate_cropResidueManagement, validate_longFallowPeriod
 
 
@@ -67,7 +70,7 @@ def validate_siteType(site: dict):
     }
 
 
-def validate_site(site: dict, nodes=[]):
+def validate_site(site: dict, node_map: dict = {}):
     """
     Validates a single `Site`.
 
@@ -75,8 +78,8 @@ def validate_site(site: dict, nodes=[]):
     ----------
     site : dict
         The `Site` to validate.
-    nodes : list
-        The list of all nodes to do cross-validation.
+    node_map : dict
+        The list of all nodes to do cross-validation, grouped by `type` and `id`.
 
     Returns
     -------
@@ -87,7 +90,7 @@ def validate_site(site: dict, nodes=[]):
         validate_site_dates(site),
         validate_date_lt_today(site, 'startDate'),
         validate_date_lt_today(site, 'endDate'),
-        validate_linked_source_privacy(site, 'defaultSource', nodes),
+        validate_linked_source_privacy(site, 'defaultSource', node_map),
         validate_siteType(site) if need_validate_coordinates(site) else True,
         validate_country(site) if 'country' in site else True,
         validate_is_region(site) if 'region' in site else True,
@@ -104,7 +107,8 @@ def validate_site(site: dict, nodes=[]):
         validate_depths(site.get('measurements')),
         validate_value_min_max(site.get('measurements')),
         validate_term_unique(site.get('measurements')),
-        validate_properties_default_value(site, 'measurements', 'properties')
+        validate_properties_default_value(site, 'measurements', 'properties'),
+        validate_require_startDate_endDate(site.get('measurements'))
     ] if 'measurements' in site else []) + flatten([
         validate_list_dates(site, 'infrastructure'),
         validate_list_dates_format(site, 'infrastructure'),
