@@ -5,7 +5,7 @@ from hestia_earth.validation.validators.cycle import (
     validate_cycle,
     validate_cycle_dates,
     validate_cycleDuration,
-    validate_functionalUnitMeasure,
+    validate_functionalUnit,
     validate_economicValueShare,
     validate_sum_aboveGroundCropResidue,
     validate_crop_residue_completeness,
@@ -80,26 +80,26 @@ def test_validate_cycleDuration_invalid():
     }
 
 
-def test_validate_functionalUnitMeasure_valid():
+def test_validate_functionalUnit_valid():
     cycle = {
-        'functionalUnitMeasure': '1 ha'
+        'functionalUnit': '1 ha'
     }
     site = {
         'siteType': 'cropland'
     }
-    assert validate_functionalUnitMeasure(cycle, site) is True
+    assert validate_functionalUnit(cycle, site) is True
 
 
-def test_validate_functionalUnitMeasure_invalid():
+def test_validate_functionalUnit_invalid():
     cycle = {
-        'functionalUnitMeasure': 'relative'
+        'functionalUnit': 'relative'
     }
     site = {
         'siteType': 'cropland'
     }
-    assert validate_functionalUnitMeasure(cycle, site) == {
+    assert validate_functionalUnit(cycle, site) == {
         'level': 'error',
-        'dataPath': '.functionalUnitMeasure',
+        'dataPath': '.functionalUnit',
         'message': 'must equal to 1 ha'
     }
 
