@@ -614,7 +614,12 @@ def test_validate_list_model_config_invalid():
         'dataPath': '.products[1].value',
         'message': 'the value provided is not consistent with the model result',
         'params': {
-            'model': {},
+            'model': {
+                '@type': 'Term',
+                '@id': 'ipcc2006',
+                'name': 'IPCC (2006)',
+                'termType': 'model'
+            },
             'term': {
                 '@type': 'Term',
                 'name': 'Above Ground Crop Residue Total',
@@ -634,7 +639,12 @@ def test_validate_list_model_config_invalid():
         'dataPath': '.products[1].value',
         'message': 'the value provided is not consistent with the model result',
         'params': {
-            'model': {},
+            'model': {
+                '@type': 'Term',
+                '@id': 'ipcc2006',
+                'name': 'IPCC (2006)',
+                'termType': 'model'
+            },
             'term': {
                 '@type': 'Term',
                 'name': 'Above Ground Crop Residue Total',
