@@ -1,3 +1,4 @@
+from unittest.mock import patch
 import json
 from hestia_earth.schema import SiteSiteType
 
@@ -6,11 +7,13 @@ from hestia_earth.validation.validators.site import (
     validate_site, validate_site_dates, validate_site_coordinates, validate_siteType
 )
 
+class_path = 'hestia_earth.validation.validators.site'
+
 
 def test_validate_valid():
     with open(f"{fixtures_path}/site/valid.json") as f:
         node = json.load(f)
-    assert validate_site(node) == [True] * 20
+    assert validate_site(node) == [True] * 21
 
 
 def test_validate_site_dates_valid():
@@ -33,13 +36,10 @@ def test_validate_site_dates_invalid():
     }
 
 
-def test_need_validate_coordinates():
+@patch(f"{class_path}.need_validate_coordinates", return_value=True)
+def test_validate_site_coordinates(*args):
     site = {'siteType': SiteSiteType.CROPLAND.value}
-    assert not validate_site_coordinates(site)
-
-    site['latitude'] = 0
-    site['longitude'] = 0
-    assert validate_site_coordinates(site) is True
+    assert validate_site_coordinates(site)
 
     site['siteType'] = SiteSiteType.SEA_OR_OCEAN.value
     assert not validate_site_coordinates(site)
